==> jc-1.4.0.tar.gz: soot/grimp/internal/GLookupSwitchStmt.h <==
// public class soot.grimp.internal.GLookupSwitchStmt

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 7c609319aad4345b soot_grimp_internal_GLookupSwitchStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 9cd610fb206a4cce soot_jimple_internal_JLookupSwitchStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JLookupSwitchStmt

#include "soot/jimple/internal/JLookupSwitchStmt.h"

#ifndef _JC_soot_grimp_internal_GLookupSwitchStmt_H_
#define _JC_soot_grimp_internal_GLookupSwitchStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Unit$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GLookupSwitchStmt$sub_refs	_jc_soot_grimp_internal_GLookupSwitchStmt$sub_refs;
typedef struct _jc_soot_grimp_internal_GLookupSwitchStmt$sub_nonrefs	_jc_soot_grimp_internal_GLookupSwitchStmt$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GLookupSwitchStmt$refs	_jc_soot_grimp_internal_GLookupSwitchStmt$refs;
typedef struct _jc_soot_grimp_internal_GLookupSwitchStmt$nonrefs	_jc_soot_grimp_internal_GLookupSwitchStmt$nonrefs;
typedef struct _jc_soot_grimp_internal_GLookupSwitchStmt$object	_jc_soot_grimp_internal_GLookupSwitchStmt$object;

typedef const struct _jc_soot_grimp_internal_GLookupSwitchStmt$vmethods	_jc_soot_grimp_internal_GLookupSwitchStmt$vmethods;
typedef const struct _jc_soot_grimp_internal_GLookupSwitchStmt$vtable	_jc_soot_grimp_internal_GLookupSwitchStmt$vtable;
typedef const struct _jc_soot_grimp_internal_GLookupSwitchStmt$vtype	_jc_soot_grimp_internal_GLookupSwitchStmt$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GLookupSwitchStmt$method$_init$d21653b680b92b7d(_jc_env *, struct _jc_soot_grimp_internal_GLookupSwitchStmt$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *, struct _jc_object *);

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GLookupSwitchStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GLookupSwitchStmt$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GLookupSwitchStmt$method_info$clone$b75f2713d6705f70;

// Static methods
extern _jc_object_array *_jc_soot_grimp_internal_GLookupSwitchStmt$method$getTargetBoxesArray$2b80c07c5813e00c(_jc_env *, struct _jc_object *);

// Virtual methods structure
struct _jc_soot_grimp_internal_GLookupSwitchStmt$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GLookupSwitchStmt$object *);
};

// Vtable
struct _jc_soot_grimp_internal_GLookupSwitchStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JLookupSwitchStmt$vmethods	soot_jimple_internal_JLookupSwitchStmt;
	_jc_soot_grimp_internal_GLookupSwitchStmt$vmethods	soot_grimp_internal_GLookupSwitchStmt;
};

// Vtype
struct _jc_soot_grimp_internal_GLookupSwitchStmt$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GLookupSwitchStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GLookupSwitchStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GLookupSwitchStmt$refs {
    _jc_soot_grimp_internal_GLookupSwitchStmt$sub_refs	soot_grimp_internal_GLookupSwitchStmt;
    _jc_soot_jimple_internal_JLookupSwitchStmt$sub_refs	soot_jimple_internal_JLookupSwitchStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GLookupSwitchStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GLookupSwitchStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JLookupSwitchStmt$sub_nonrefs	soot_jimple_internal_JLookupSwitchStmt;
    _jc_soot_grimp_internal_GLookupSwitchStmt$sub_nonrefs	soot_grimp_internal_GLookupSwitchStmt;
};

// Object instance structure
struct _jc_soot_grimp_internal_GLookupSwitchStmt$object {
	_jc_soot_grimp_internal_GLookupSwitchStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GLookupSwitchStmt$vtype	*vtype;
	_jc_soot_grimp_internal_GLookupSwitchStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GLookupSwitchStmt$vtype _jc_soot_grimp_internal_GLookupSwitchStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GLookupSwitchStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GLookupSwitchStmt$class_object;

#endif	/* _JC_soot_grimp_internal_GLookupSwitchStmt_H_ */

==> jc-1.4.6.tar.gz: soot/grimp/internal/GLookupSwitchStmt.h <==
// public class soot.grimp.internal.GLookupSwitchStmt

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2492f1f7a753b788 soot_AbstractUnit
// @dep_class 7c609319aad4345b soot_grimp_internal_GLookupSwitchStmt
// @dep_class b3c0d2cd30f6acdd soot_jimple_internal_AbstractStmt
// @dep_class 9cd610fb206a4cce soot_jimple_internal_JLookupSwitchStmt
// @dep_class 6ddedfee878f127 soot_tagkit_AbstractHost

// header file dependencies
// @dep_header soot_jimple_internal_JLookupSwitchStmt

#include "soot/jimple/internal/JLookupSwitchStmt.h"

#ifndef _JC_soot_grimp_internal_GLookupSwitchStmt_H_
#define _JC_soot_grimp_internal_GLookupSwitchStmt_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_List$object;
struct _jc_soot_Unit$object;
struct _jc_soot_Value$object;

// Typedefs
typedef struct _jc_soot_grimp_internal_GLookupSwitchStmt$sub_refs	_jc_soot_grimp_internal_GLookupSwitchStmt$sub_refs;
typedef struct _jc_soot_grimp_internal_GLookupSwitchStmt$sub_nonrefs	_jc_soot_grimp_internal_GLookupSwitchStmt$sub_nonrefs;
typedef struct _jc_soot_grimp_internal_GLookupSwitchStmt$refs	_jc_soot_grimp_internal_GLookupSwitchStmt$refs;
typedef struct _jc_soot_grimp_internal_GLookupSwitchStmt$nonrefs	_jc_soot_grimp_internal_GLookupSwitchStmt$nonrefs;
typedef struct _jc_soot_grimp_internal_GLookupSwitchStmt$object	_jc_soot_grimp_internal_GLookupSwitchStmt$object;

typedef const struct _jc_soot_grimp_internal_GLookupSwitchStmt$vmethods	_jc_soot_grimp_internal_GLookupSwitchStmt$vmethods;
typedef const struct _jc_soot_grimp_internal_GLookupSwitchStmt$vtable	_jc_soot_grimp_internal_GLookupSwitchStmt$vtable;
typedef const struct _jc_soot_grimp_internal_GLookupSwitchStmt$vtype	_jc_soot_grimp_internal_GLookupSwitchStmt$vtype;

// Constructors
extern void _jc_soot_grimp_internal_GLookupSwitchStmt$method$_init$d21653b680b92b7d(_jc_env *, struct _jc_soot_grimp_internal_GLookupSwitchStmt$object *, struct _jc_object *, struct _jc_object *, struct _jc_object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_Object$object *_jc_soot_grimp_internal_GLookupSwitchStmt$method$clone$b75f2713d6705f70(_jc_env *, struct _jc_soot_grimp_internal_GLookupSwitchStmt$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_grimp_internal_GLookupSwitchStmt$method_info$clone$b75f2713d6705f70;

// Static methods
extern _jc_object_array *_jc_soot_grimp_internal_GLookupSwitchStmt$method$getTargetBoxesArray$2b80c07c5813e00c(_jc_env *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_grimp_internal_GLookupSwitchStmt$vmethods {
	struct _jc_java_lang_Object$object	*(*clone$b75f2713d6705f70)(_jc_env *, struct _jc_soot_grimp_internal_GLookupSwitchStmt$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_grimp_internal_GLookupSwitchStmt$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_AbstractHost$vmethods	soot_tagkit_AbstractHost;
	_jc_soot_AbstractUnit$vmethods	soot_AbstractUnit;
	_jc_soot_jimple_internal_AbstractStmt$vmethods	soot_jimple_internal_AbstractStmt;
	_jc_soot_jimple_internal_JLookupSwitchStmt$vmethods	soot_jimple_internal_JLookupSwitchStmt;
	_jc_soot_grimp_internal_GLookupSwitchStmt$vmethods	soot_grimp_internal_GLookupSwitchStmt;
};

// Vtype
struct _jc_soot_grimp_internal_GLookupSwitchStmt$vtype {
	_jc_type			type;
	_jc_soot_grimp_internal_GLookupSwitchStmt$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_grimp_internal_GLookupSwitchStmt$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_grimp_internal_GLookupSwitchStmt$refs {
    _jc_soot_grimp_internal_GLookupSwitchStmt$sub_refs	soot_grimp_internal_GLookupSwitchStmt;
    _jc_soot_jimple_internal_JLookupSwitchStmt$sub_refs	soot_jimple_internal_JLookupSwitchStmt;
    _jc_soot_jimple_internal_AbstractStmt$sub_refs	soot_jimple_internal_AbstractStmt;
    _jc_soot_AbstractUnit$sub_refs	soot_AbstractUnit;
    _jc_soot_tagkit_AbstractHost$sub_refs	soot_tagkit_AbstractHost;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_grimp_internal_GLookupSwitchStmt$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_grimp_internal_GLookupSwitchStmt$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_AbstractHost$sub_nonrefs	soot_tagkit_AbstractHost;
    _jc_soot_AbstractUnit$sub_nonrefs	soot_AbstractUnit;
    _jc_soot_jimple_internal_AbstractStmt$sub_nonrefs	soot_jimple_internal_AbstractStmt;
    _jc_soot_jimple_internal_JLookupSwitchStmt$sub_nonrefs	soot_jimple_internal_JLookupSwitchStmt;
    _jc_soot_grimp_internal_GLookupSwitchStmt$sub_nonrefs	soot_grimp_internal_GLookupSwitchStmt;
};

// Object instance structure
struct _jc_soot_grimp_internal_GLookupSwitchStmt$object {
	_jc_soot_grimp_internal_GLookupSwitchStmt$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_grimp_internal_GLookupSwitchStmt$vtype	*vtype;
	_jc_soot_grimp_internal_GLookupSwitchStmt$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_grimp_internal_GLookupSwitchStmt$vtype _jc_soot_grimp_internal_GLookupSwitchStmt$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_grimp_internal_GLookupSwitchStmt, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_grimp_internal_GLookupSwitchStmt$class_object;

#endif	/* _JC_soot_grimp_internal_GLookupSwitchStmt_H_ */
